@@ -6,14 +6,14 @@
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "openbsd3.8"
+#define HOST_OS "openbsd3.9"
 #define HOST_OS_NAME "openbsd3"
-#define HOST_OS_VERSION "3.8"
+#define HOST_OS_VERSION "3.9"
 #define HOST_ARCH "i386"
 #define DISTRO_NAME "none"
-#define HOST_NAME "a-openbsd38.fsl.cs.sunysb.edu"
+#define HOST_NAME "a-openbsd39.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Thu May 11 11:56:51 EST 2006"
+#define CONFIG_DATE "Thu May 11 11:59:53 EST 2006"
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_VERSION "6.2a2"
 #define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
@@ -28,12 +28,13 @@
 #define HAVE_MEMORY_H 1
 #define HAVE_STRINGS_H 1
 #define HAVE_INTTYPES_H 1
+#define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
 #ifdef __cplusplus
 #include <stdlib.h>
 #endif
-#define HOST_HEADER_VERSION "3.8"
+#define HOST_HEADER_VERSION "3.9"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_UNISTD_H 1
@@ -302,16 +303,21 @@
 #define HAVE_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_SUN 1
+#define HAVE_WAITPID 1
 #define HAVE_MAP_EXEC 1
 #define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_CDFS 1
-#define HAVE_FS_LOFS 1
 #define HAVE_FS_MFS 1
 #define HAVE_FS_NFS 1
 #define HAVE_FS_PCFS 1
@@ -334,16 +340,17 @@
 #define MOUNT_TYPE_CDFS MOUNT_CD9660
 #define MOUNT_TYPE_PCFS MOUNT_MSDOS
 #define MOUNT_TYPE_MFS MOUNT_MFS
-#define MOUNT_TYPE_LOFS MOUNT_LOFS
 #define MOUNT_TYPE_LFS MOUNT_LFS
 #define MOUNT_TYPE_AFS MOUNT_AFS
 #define MNTTAB_TYPE_NFS "nfs"
-#define MNTTAB_TYPE_NFS3 "nfs3"
-#define MNTTAB_TYPE_UFS "ufs"
-#define MNTTAB_TYPE_CDFS "cdfs"
-#define MNTTAB_TYPE_PCFS "pcfs"
+#define MNTTAB_TYPE_NFS3 "nfs"
+#define MNTTAB_TYPE_UFS "ffs"
+#define MNTTAB_TYPE_XFS "xfs"
+#define MNTTAB_TYPE_CDFS "cd9660"
+#define MNTTAB_TYPE_PCFS "msdos"
 #define MNTTAB_TYPE_MFS "mfs"
-#define MNTTAB_TYPE_LOFS "lofs"
+#define MNTTAB_TYPE_LFS "lfs"
+#define MNTTAB_TYPE_AFS "afs"
 #define MNT2_GEN_OPT_ASYNC 0x40
 #define MNT2_GEN_OPT_FORCE 0x80000
 #define MNT2_GEN_OPT_NODEV 0x10
@@ -381,4 +388,5 @@
 #define MNT2_PCFS_OPT_NOWIN95 0x4
 #define MNT2_PCFS_OPT_SHORTNAME 0x1
 #define HIDE_MOUNT_TYPE "nfs"
+#define HAVE_GETMNTINFO 1
 #define USE_CONNECTED_NFS_SOCKETS 1
